/* tc-m68hc05.h -- Motorola 68HC05 assembler
   Copyright 2004 Free Software Foundation, Inc.
   Copyright 2004 Martin Kgler
   Contributed by Martin Kgler (mkoegler@auto.tuwien.ac.at)

   This file is part of GAS, the GNU Assembler.

   GAS is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   GAS is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with GAS; see the file COPYING.  If not, write to the Free
   Software Foundation, 51 Franklin Street - Fifth Floor, Boston, MA
   02110-1301, USA.  */

/* By convention, you should define this macro in the `.h' file.  For
   example, `tc-m68k.h' defines `TC_M68K'.  You might have to use this
   if it is necessary to add CPU specific code to the object format
   file.  */
#define TC_M68HC05

/* This macro is the BFD target name to use when creating the output
   file.  This will normally depend upon the `OBJ_FMT' macro.  */
#define TARGET_FORMAT "elf32-m68hc05"

/* This macro is the BFD architecture to pass to `bfd_set_arch_mach'.  */
#define TARGET_ARCH bfd_arch_m68hc05

/* This macro is the BFD machine number to pass to
   `bfd_set_arch_mach'.  If it is not defined, GAS will use 0.  */
#define TARGET_MACH 0

/* You should define this macro to be non-zero if the target is big
   endian, and zero if the target is little endian.  */
#define TARGET_BYTES_BIG_ENDIAN 1

/* If you define this macro, GAS will warn about the use of
   nonstandard escape sequences in a string.  */
/*#define ONLY_STANDARD_ESCAPES*/

/* GAS will call this function for any expression that can not be
   recognized.  When the function is called, `input_line_pointer'
   will point to the start of the expression.  */
#define md_operand(x)

/* This should just call either `number_to_chars_bigendian' or
   `number_to_chars_littleendian', whichever is appropriate.  On
   targets like the MIPS which support options to change the
   endianness, which function to call is a runtime decision.  On
   other targets, `md_number_to_chars' can be a simple macro.  */
#define md_number_to_chars number_to_chars_bigendian

/* `md_short_jump_size'
   `md_long_jump_size'
   `md_create_short_jump'
   `md_create_long_jump'
   If `WORKING_DOT_WORD' is defined, GAS will not do broken word
   processing (*note Broken words::.).  Otherwise, you should set
   `md_short_jump_size' to the size of a short jump (a jump that is
   just long enough to jump around a long jmp) and
   `md_long_jump_size' to the size of a long jump (a jump that can go
   anywhere in the function), You should define
   `md_create_short_jump' to create a short jump around a long jump,
   and define `md_create_long_jump' to create a long jump.  */
#define WORKING_DOT_WORD

/* If you define this macro, it should return the offset between the
   address of a PC relative fixup and the position from which the PC
   relative adjustment should be made.  On many processors, the base
   of a PC relative instruction is the next instruction, so this
   macro would return the length of an instruction.  */
#define MD_PCREL_FROM_SECTION(FIX, SEC) md_pcrel_from_section(FIX, SEC)
extern long md_pcrel_from_section PARAMS ((struct fix *, segT));

/*select part of addresses*/
typedef enum
{ O_NONE, O_LO8, O_HI8, O_HLO8, O_HHI8, O_HI16, O_LO16, O_OFFSET8, O_OFFSET16 }
m68hc05_op;


typedef struct
{
  /*opcodes for different sizes */
  unsigned char opcode1, opcode2, opcode3;
  /*which part of address */
  m68hc05_op reloc_info;
  /*type */
  enum
  { REL_NONE, REL_8_16, REL_8_16_0, REL_8_PCREL, REL_ADDR_8_PCREL }
  relax_type;
  /*symbol */
  symbolS *addsym;
  /*offset */
  offsetT off;
} m68hc05_relax;

/*type used to store relaxation information*/
#define TC_FRAG_TYPE m68hc05_relax

/* No shared lib support, so we don't need to ensure externally
   visible symbols can be overridden.  */
#define EXTERN_FORCE_RELOC 0

/* We need to force out some relocations when relaxing.  */
#define TC_FORCE_RELOCATION(fix) tc_m68hc05_force_relocation (fix)
extern int tc_m68hc05_force_relocation (struct fix *);

#define tc_fix_adjustable(X) tc_m68hc05_fix_adjustable(X)
extern int tc_m68hc05_fix_adjustable (struct fix *);

#define tc_canonicalize_section_name(c) m68hc05_rewrite_name(c)
extern char *m68hc05_rewrite_name (char *name);

/* You may define this macro to parse an expression used in a data
   allocation pseudo-op such as `.word'.  You can use this to
   recognize relocation directives that may appear in such directives.  */
#define TC_PARSE_CONS_EXPRESSION(EXPR,N) m68hc05_parse_cons_expression (EXPR,N)
void m68hc05_parse_cons_expression (expressionS * exp, int nbytes);

/* You may define this macro to generate a fixup for a data
   allocation pseudo-op.  */
#define TC_CONS_FIX_NEW(FRAG,WHERE,N,EXP) m68hc05_cons_fix_new(FRAG,WHERE,N,EXP)
void m68hc05_cons_fix_new (fragS * frag, int where, int nbytes,
			   expressionS * exp);

/* Define TC_M68K so that we can use the MRI mode.  */
#define TC_M68K
